@@ -13,11 +13,11 @@ from ...models.fields import CollectionItem
 from .base import CloudinaryFieldFile, CloudinaryFileResource
 
 __all__ = [
-    'CloudinaryFileItem',
-    'CloudinaryMediaItem',
-    'CloudinaryImageItem',
-    'CloudinaryCollection',
-    'CloudinaryImageCollection',
+    "CloudinaryFileItem",
+    "CloudinaryMediaItem",
+    "CloudinaryImageItem",
+    "CloudinaryCollection",
+    "CloudinaryImageCollection",
 ]
 
 
@@ -39,21 +39,21 @@ class CollectionCloudinaryFileItemBase(CollectionItemBase, CloudinaryFileResourc
 
 
 class CloudinaryFileItem(FilePreviewMixin, CollectionCloudinaryFileItemBase):
-    change_form_class = 'paper_uploads.forms.dialogs.collection.FileItemDialog'
-    template_name = 'paper_uploads/collection_item/file.html'
-    preview_template_name = 'paper_uploads/collection_item/preview/file.html'
+    change_form_class = "paper_uploads.forms.dialogs.collection.FileItemDialog"
+    template_name = "paper_uploads/items/file.html"
+    preview_template_name = "paper_uploads/items/preview/file.html"
 
     file = CloudinaryField(
-        _('file'),
+        _("file"),
         type=settings.CLOUDINARY_TYPE,
-        resource_type='raw',
+        resource_type="raw",
         folder=settings.COLLECTION_FILES_UPLOAD_TO
     )
-    display_name = models.CharField(_('display name'), max_length=255, blank=True)
+    display_name = models.CharField(_("display name"), max_length=255, blank=True)
 
     class Meta(CollectionCloudinaryFileItemBase.Meta):
-        verbose_name = _('File item')
-        verbose_name_plural = _('File items')
+        verbose_name = _("File item")
+        verbose_name_plural = _("File items")
 
     def save(self, *args, **kwargs):
         if not self.pk and not self.display_name:
@@ -69,7 +69,7 @@ class CloudinaryFileItem(FilePreviewMixin, CollectionCloudinaryFileItemBase):
         self.file = value
 
     def get_file_field(self) -> CloudinaryField:
-        return self._meta.get_field('file')
+        return self._meta.get_field("file")
 
     @classmethod
     def file_supported(cls, file: File) -> bool:
@@ -77,21 +77,21 @@ class CloudinaryFileItem(FilePreviewMixin, CollectionCloudinaryFileItemBase):
 
 
 class CloudinaryMediaItem(FilePreviewMixin, CollectionCloudinaryFileItemBase):
-    change_form_class = 'paper_uploads.forms.dialogs.collection.FileItemDialog'
-    template_name = 'paper_uploads/collection_item/file.html'
-    preview_template_name = 'paper_uploads/collection_item/preview/file.html'
+    change_form_class = "paper_uploads.forms.dialogs.collection.FileItemDialog"
+    template_name = "paper_uploads/items/file.html"
+    preview_template_name = "paper_uploads/items/preview/file.html"
 
     file = CloudinaryField(
-        _('file'),
+        _("file"),
         type=settings.CLOUDINARY_TYPE,
-        resource_type='video',
+        resource_type="video",
         folder=settings.COLLECTION_FILES_UPLOAD_TO
     )
-    display_name = models.CharField(_('display name'), max_length=255, blank=True)
+    display_name = models.CharField(_("display name"), max_length=255, blank=True)
 
     class Meta(CollectionCloudinaryFileItemBase.Meta):
-        verbose_name = _('Media item')
-        verbose_name_plural = _('Media items')
+        verbose_name = _("Media item")
+        verbose_name_plural = _("Media items")
 
     def save(self, *args, **kwargs):
         if not self.pk and not self.display_name:
@@ -107,32 +107,32 @@ class CloudinaryMediaItem(FilePreviewMixin, CollectionCloudinaryFileItemBase):
         self.file = value
 
     def get_file_field(self) -> CloudinaryField:
-        return self._meta.get_field('file')
+        return self._meta.get_field("file")
 
     @classmethod
     def file_supported(cls, file: File) -> bool:
         mimetype = magic.from_buffer(file.read(1024), mime=True)
         file.seek(0)  # correct file position after mimetype detection
-        basetype, subtype = mimetype.split('/', 1)
-        return basetype in {'video', 'audio'}
+        basetype, subtype = mimetype.split("/", 1)
+        return basetype in {"video", "audio"}
 
 
 class CloudinaryImageItem(ImageFileResourceMixin, CollectionCloudinaryFileItemBase):
     PREVIEW_VARIATIONS = settings.COLLECTION_IMAGE_ITEM_PREVIEW_VARIATIONS
-    change_form_class = 'paper_uploads.forms.dialogs.collection.ImageItemDialog'
-    template_name = 'paper_uploads_cloudinary/collection_item/image.html'
-    preview_template_name = 'paper_uploads_cloudinary/collection_item/preview/image.html'
+    change_form_class = "paper_uploads.forms.dialogs.collection.ImageItemDialog"
+    template_name = "paper_uploads_cloudinary/items/image.html"
+    preview_template_name = "paper_uploads_cloudinary/items/preview/image.html"
 
     file = CloudinaryField(
-        _('file'),
+        _("file"),
         type=settings.CLOUDINARY_TYPE,
-        resource_type='image',
+        resource_type="image",
         folder=settings.COLLECTION_IMAGES_UPLOAD_TO
     )
 
     class Meta(CollectionCloudinaryFileItemBase.Meta):
-        verbose_name = _('Image item')
-        verbose_name_plural = _('Image items')
+        verbose_name = _("Image item")
+        verbose_name_plural = _("Image items")
 
     def get_file(self) -> Optional[CloudinaryFieldFile]:
         if not self.file:
@@ -143,14 +143,14 @@ class CloudinaryImageItem(ImageFileResourceMixin, CollectionCloudinaryFileItemBa
         self.file = value
 
     def get_file_field(self) -> CloudinaryField:
-        return self._meta.get_field('file')
+        return self._meta.get_field("file")
 
     @classmethod
     def file_supported(cls, file: File) -> bool:
         mimetype = magic.from_buffer(file.read(1024), mime=True)
         file.seek(0)  # correct file position after mimetype detection
-        basetype, subtype = mimetype.split('/', 1)
-        return basetype == 'image'
+        basetype, subtype = mimetype.split("/", 1)
+        return basetype == "image"
 
 
 # ==============================================================================
@@ -167,8 +167,15 @@ class CloudinaryImageCollection(Collection):
 
     @classmethod
     def get_configuration(cls) -> Dict[str, Any]:
-        # TODO: магический метод
         return {
-            'image': True,
-            'acceptFiles': ['image/*'],
+            "strictImageValidation": True,
+            "acceptFiles": [
+                "image/bmp",
+                "image/gif",
+                "image/jpeg",
+                "image/png",
+                # "image/svg+xml",
+                "image/tiff",
+                "image/webp",
+            ],
         }
