@@ -2,25 +2,25 @@ from typing import Any, Dict, Optional
 
 from cloudinary.models import CloudinaryField
 from django.db import models
-from django.template.defaultfilters import filesizeformat
 from django.utils.translation import gettext_lazy as _
 
 from ...conf import settings
+from ...utils import filesizeformat
 from .base import CloudinaryFieldFile, CloudinaryFileResource
 
 
 class CloudinaryFile(CloudinaryFileResource):
     file = CloudinaryField(
-        _('file'),
+        _("file"),
         type=settings.CLOUDINARY_TYPE,
-        resource_type='raw',
+        resource_type="raw",
         folder=settings.FILES_UPLOAD_TO
     )
-    display_name = models.CharField(_('display name'), max_length=255, blank=True)
+    display_name = models.CharField(_("display name"), max_length=255, blank=True)
 
     class Meta(CloudinaryFileResource.Meta):
-        verbose_name = _('file')
-        verbose_name_plural = _('files')
+        verbose_name = _("file")
+        verbose_name_plural = _("files")
 
     def get_file(self) -> Optional[CloudinaryFieldFile]:
         if not self.file:
@@ -31,7 +31,7 @@ class CloudinaryFile(CloudinaryFileResource):
         self.file = value
 
     def get_file_field(self) -> CloudinaryField:
-        return self._meta.get_field('file')
+        return self._meta.get_field("file")
 
     def save(self, *args, **kwargs):
         if not self.pk and not self.display_name:
@@ -41,8 +41,8 @@ class CloudinaryFile(CloudinaryFileResource):
     def as_dict(self) -> Dict[str, Any]:
         return {
             **super().as_dict(),
-            'name': self.display_name,
-            'file_info': '({ext}, {size})'.format(
+            "name": self.display_name,
+            "file_info": "({ext}, {size})".format(
                 ext=self.extension, size=filesizeformat(self.size)
             ),
         }
