@@ -1,8 +1,10 @@
+from datetime import timedelta
+
 from django.apps import apps
 from django.contrib.contenttypes.models import ContentType
 from django.core.management import BaseCommand
 from django.db import DEFAULT_DB_ALIAS, models, transaction
-from django.utils.timezone import now, timedelta
+from django.utils.timezone import now
 from polymorphic.models import PolymorphicModel
 
 from ...models.base import FileResource
@@ -10,30 +12,41 @@ from ...models.collection import CollectionBase
 
 
 class Command(BaseCommand):
+    help = """
+    Поиск и удаление экземпляров файловых моделей с утерянными файлами.
+    Также удаляются экземпляров файловых моделей, на которые нет ссылок.
+    
+    Создание экземпляра файловой модели и загрузка в неё файла - это 
+    две отдельные операции. Между ними может пройти какое-то время.
+    Для того, чтобы сохранить экземпляры, в которые ещё не загрузились файлы,
+    эта команда пропускает те экземпляры, которые созданы раньше, чем
+    `--min-age` минут назад. Значение параметра `--min-age` по умолчанию 
+    установлено в 30 минут.
+    """
     verbosity = None
     database = DEFAULT_DB_ALIAS
     interactive = True
 
     def add_arguments(self, parser):
         parser.add_argument(
-            '--min-age',
+            "--min-age",
             type=int,
             default=30,
-            help='Minimum instance age in minutes to look for',
+            help="Minimum instance age in minutes to look for",
         )
         parser.add_argument(
-            '--database',
-            action='store',
-            dest='database',
+            "--database",
+            action="store",
+            dest="database",
             default=DEFAULT_DB_ALIAS,
-            help='Nominates the database to use. Defaults to the "default" database.',
+            help="Nominates the database to use. Defaults to the 'default' database.",
         )
         parser.add_argument(
-            '--noinput',
-            '--no-input',
-            action='store_false',
-            dest='interactive',
-            help='Do NOT prompt the user for input of any kind.',
+            "--noinput",
+            "--no-input",
+            action="store_false",
+            dest="interactive",
+            help="Do NOT prompt the user for input of any kind.",
         )
 
     @staticmethod
@@ -69,9 +82,6 @@ class Command(BaseCommand):
                 continue
 
             with transaction.atomic(self.database):
-                # db_cursor = connections[self.database].cursor()
-                # db_cursor.execute('LOCK TABLE %s IN ACCESS SHARE MODE' % model._meta.db_table)
-
                 for field in fields:
                     used_values = (
                         model._base_manager.using(self.database)
@@ -103,28 +113,28 @@ class Command(BaseCommand):
         if self.interactive:
             while True:
                 answer = input(
-                    'Found \033[92m%d unused %s\033[0m objects. '
-                    'What would you like to do with them?\n'
-                    '(p)rint / (k)eep / (d)elete [default=keep]? '
+                    "Found \033[92m%d unused %s\033[0m objects. "
+                    "What would you like to do with them?\n"
+                    "(p)rint / (k)eep / (d)elete [default=keep]? "
                     % (unused_count, related_model.__name__)
                 )
-                answer = answer.lower() or 'k'
-                if answer in {'p', 'print'}:
-                    self.stdout.write('\n')
-                    qs = unused_qs.order_by('pk').only('file')
+                answer = answer.lower() or "k"
+                if answer in {"p", "print"}:
+                    self.stdout.write("\n")
+                    qs = unused_qs.order_by("pk").only("file")
                     for index, item in enumerate(qs, start=1):
                         self.stdout.write(
-                            '  {}) {} #{} (File: {})'.format(
+                            "  {}) {} #{} (File: {})".format(
                                 index,
                                 type(item).__name__,
                                 item.pk,
                                 item.name,
                             )
                         )
-                    self.stdout.write('\n')
-                elif answer in {'k', 'keep'}:
+                    self.stdout.write("\n")
+                elif answer in {"k", "keep"}:
                     return
-                elif answer in {'d', 'delete'}:
+                elif answer in {"d", "delete"}:
                     unused_qs.delete()
                     return
 
@@ -152,47 +162,49 @@ class Command(BaseCommand):
         if self.interactive:
             while True:
                 answer = input(
-                    'Found \033[92m%d %s\033[0m objects which are linked to a non-existent files.\n'
-                    'What would you like to do with them?\n'
-                    '(p)rint / (k)eep / (d)elete [default=keep]? '
+                    "Found \033[92m%d %s\033[0m objects which are linked to a non-existent files.\n"
+                    "What would you like to do with them?\n"
+                    "(p)rint / (k)eep / (d)elete [default=keep]? "
                     % (len(sourceless_items), related_model.__name__)
                 )
-                answer = answer.lower() or 'k'
-                if answer in {'p', 'print'}:
-                    self.stdout.write('\n')
+                answer = answer.lower() or "k"
+                if answer in {"p", "print"}:
+                    self.stdout.write("\n")
                     qs = (
                         queryset.filter(pk__in=sourceless_items)
-                        .order_by('pk')
-                        .only('file')
+                        .order_by("pk")
+                        .only("file")
                     )
                     for index, item in enumerate(qs, start=1):
                         self.stdout.write(
-                            '  {}) {} #{} (File: {})'.format(
+                            "  {}) {} #{} (File: {})".format(
                                 index,
                                 type(item).__name__,
                                 item.pk,
                                 item.name,
                             )
                         )
-                    self.stdout.write('\n')
-                elif answer in {'k', 'keep'}:
+                    self.stdout.write("\n")
+                elif answer in {"k", "keep"}:
                     return
-                elif answer in {'d', 'delete'}:
+                elif answer in {"d", "delete"}:
                     queryset.filter(pk__in=sourceless_items).delete()
                     return
 
     def handle(self, *args, **options):
-        self.verbosity = options['verbosity']
-        self.database = options['database']
-        self.interactive = options['interactive']
+        self.verbosity = options["verbosity"]
+        self.database = options["database"]
+        self.interactive = options["interactive"]
 
-        min_age = now() - timedelta(minutes=options['min_age'])
+        min_age = now() - timedelta(minutes=options["min_age"])
 
         for model in apps.get_models():
             if not issubclass(model, FileResource):
                 continue
+
             if issubclass(model, PolymorphicModel):
                 continue
+
             if model._meta.abstract:
                 continue
 
@@ -206,13 +218,15 @@ class Command(BaseCommand):
         for model in apps.get_models():
             if not issubclass(model, FileResource):
                 continue
+
             if not issubclass(model, PolymorphicModel):
                 continue
+
             if model._meta.abstract:
                 continue
 
             self.clean_source_missing(
-                model._base_manager.using(self.database).non_polymorphic()
+                model.objects.using(self.database).non_polymorphic()
             )
 
         # Do not touch fresh galleries - they may not be saved yet.
