@@ -11,16 +11,16 @@ from .file import UploadedFile
 from .image import UploadedImage
 
 __all__ = [
-    'UploadedFile',
-    'UploadedImage',
-    'FileField',
-    'ImageField',
-    'CollectionField',
-    'CollectionItemBase',
-    'CollectionItem',
-    'Collection',
-    'ImageCollection',
-    'FileItem',
-    'SVGItem',
-    'ImageItem',
+    "UploadedFile",
+    "UploadedImage",
+    "FileField",
+    "ImageField",
+    "CollectionField",
+    "CollectionItemBase",
+    "CollectionItem",
+    "Collection",
+    "ImageCollection",
+    "FileItem",
+    "SVGItem",
+    "ImageItem",
 ]
