@@ -17,27 +17,28 @@ from django.template import loader
 from django.utils.module_loading import import_string
 from django.utils.timezone import now
 from django.utils.translation import gettext_lazy as _
+from polymorphic.base import PolymorphicModelBase
 from polymorphic.models import PolymorphicModel
 
 from ..conf import FILE_ICON_DEFAULT, FILE_ICON_OVERRIDES, settings
 from ..helpers import _get_item_types, _set_item_types, build_variations
 from ..storage import upload_storage
 from ..variations import PaperVariation
-from .base import FileFieldResource, VersatileImageResourceMixin
+from .base import NoPermissionsMetaBase, ResourceBaseMeta, FileFieldResource, VersatileImageResourceMixin
 from .fields import CollectionItem
 from .fields.collection import ContentItemRelation
 from .image import VariationalFileField
 from .mixins import BacklinkModelMixin
 
 __all__ = [
-    'CollectionItemBase',
-    'CollectionBase',
-    'FilePreviewMixin',
-    'FileItem',
-    'SVGItem',
-    'ImageItem',
-    'Collection',
-    'ImageCollection',
+    "CollectionItemBase",
+    "CollectionBase",
+    "FilePreviewMixin",
+    "FileItem",
+    "SVGItem",
+    "ImageItem",
+    "Collection",
+    "ImageCollection",
 ]
 
 
@@ -55,7 +56,7 @@ class ItemTypesDescriptor:
         if cls is None:
             cls = type(instance)
 
-        cache_attname = '_{}__item_type_cache'.format(cls.__name__)
+        cache_attname = "_{}__item_type_cache".format(cls.__name__)
         if hasattr(cls, cache_attname):
             return OrderedDict(getattr(cls, cache_attname))
 
@@ -79,25 +80,26 @@ class ItemTypesDescriptor:
         return item_types
 
 
-class CollectionMetaclass(ModelBase):
+class CollectionMeta(NoPermissionsMetaBase, ModelBase):
     """
-    Хак, создающий прокси-модели вместо наследования, если явно не указано обратное.
+    Хак, при котором вместо наследования создаются прокси-модели,
+    если явно не указано обратное.
     """
 
     @classmethod
     def __prepare__(cls, name, bases):
         return OrderedDict()
 
-    def __new__(mcs, name, bases, attrs, **kwargs):
+    def __new__(mcs, name, bases, attrs, **kwargs):  # noqa: N804
         # set proxy=True by default
-        meta = attrs.pop('Meta', None)
+        meta = attrs.pop("Meta", None)
         if meta is None:
-            meta = type('Meta', (), {'proxy': True})
+            meta = type("Meta", (), {"proxy": True})
         else:
             meta_attrs = meta.__dict__.copy()
-            meta_attrs.setdefault('proxy', True)
-            meta = type('Meta', meta.__bases__, meta_attrs)
-        attrs['Meta'] = meta
+            meta_attrs.setdefault("proxy", True)
+            meta = type("Meta", meta.__bases__, meta_attrs)
+        attrs["Meta"] = meta
 
         # сохраняем явно объявленные (не унаследованные) типы элементов коллекции
         # в приватное поле класса
@@ -108,25 +110,25 @@ class CollectionMetaclass(ModelBase):
 
         new_class = super().__new__(mcs, name, bases, attrs, **kwargs)
         _set_item_types(new_class, item_types)
-        new_class.item_types = ItemTypesDescriptor('item_types')
+        new_class.item_types = ItemTypesDescriptor("item_types")
         return new_class
 
 
-class CollectionBase(BacklinkModelMixin, metaclass=CollectionMetaclass):
+class CollectionBase(BacklinkModelMixin, metaclass=CollectionMeta):
     items = ContentItemRelation(
-        'paper_uploads.CollectionItemBase',
-        content_type_field='collection_content_type',
-        object_id_field='collection_id',
+        "paper_uploads.CollectionItemBase",
+        content_type_field="collection_content_type",
+        object_id_field="collection_id",
         for_concrete_model=False,
     )
-    created_at = models.DateTimeField(_('created at'), default=now, editable=False)
+    created_at = models.DateTimeField(_("created at"), default=now, editable=False)
 
     class Meta:
         proxy = False
         abstract = True
         default_permissions = ()
-        verbose_name = _('collection')
-        verbose_name_plural = _('collectionы')
+        verbose_name = _("collection")
+        verbose_name_plural = _("collections")
 
     @classmethod
     def _check_fields(cls, **kwargs):
@@ -138,10 +140,10 @@ class CollectionBase(BacklinkModelMixin, metaclass=CollectionMetaclass):
     def get_items(self, item_type: str = None) -> 'models.QuerySet[CollectionItemBase]':
         # TODO: что если класс элемента был удален из коллекции, но элементы остались?
         if item_type is None:
-            return self.items.order_by('order')
+            return self.items.order_by("order")
         if item_type not in self.item_types:
-            raise ValueError(_('Unsupported collection item type: %s') % item_type)
-        return self.items.filter(item_type=item_type).order_by('order')
+            raise ValueError(_("Unsupported collection item type: %s") % item_type)
+        return self.items.filter(item_type=item_type).order_by("order")
 
     def detect_item_type(self, *args, **kwargs) -> Optional[str]:
         """
@@ -149,7 +151,7 @@ class CollectionBase(BacklinkModelMixin, metaclass=CollectionMetaclass):
         на возможность представления данных, переданных в параметрах.
         """
         for item_type, field in self.item_types.items():
-            if hasattr(field.model, 'file_supported'):
+            if hasattr(field.model, "file_supported"):
                 if field.model.file_supported(*args, **kwargs):
                     yield item_type
 
@@ -178,7 +180,7 @@ class Collection(CollectionBase):
 
     class Meta:
         proxy = False  # явно указываем, что это не прокси-модель
-        default_manager_name = 'default_mgr'
+        default_manager_name = "default_mgr"
 
     def save(self, *args, **kwargs):
         if not self.collection_content_type:
@@ -191,7 +193,11 @@ class Collection(CollectionBase):
 # ======================================================================================
 
 
-class CollectionItemBase(PolymorphicModel):
+class CollectionItemMetaBase(PolymorphicModelBase, ResourceBaseMeta):
+    pass
+
+
+class CollectionItemBase(PolymorphicModel, metaclass=CollectionItemMetaBase):
     """
     Базовый класс элемента коллекции.
     """
@@ -211,20 +217,19 @@ class CollectionItemBase(PolymorphicModel):
     collection_content_type = models.ForeignKey(ContentType, on_delete=models.CASCADE)
     collection_id = models.IntegerField()
     collection = GenericForeignKey(
-        ct_field='collection_content_type',
-        fk_field='collection_id',
+        ct_field="collection_content_type",
+        fk_field="collection_id",
         for_concrete_model=False,
     )
 
     item_type = models.CharField(
-        _('type'), max_length=32, db_index=True, editable=False
+        _("type"), max_length=32, db_index=True, editable=False
     )
-    order = models.IntegerField(_('order'), default=0, editable=False)
+    order = models.IntegerField(_("order"), default=0, editable=False)
 
     class Meta:
-        default_permissions = ()
-        verbose_name = _('item')
-        verbose_name_plural = _('items')
+        verbose_name = _("item")
+        verbose_name_plural = _("items")
 
     @classmethod
     def check(cls, **kwargs):
@@ -236,7 +241,7 @@ class CollectionItemBase(PolymorphicModel):
 
     @classmethod
     def _check_form_class(cls, **kwargs):
-        flag = '_{}__BaseCollectionItem'.format(cls.__name__)
+        flag = "_{}__BaseCollectionItem".format(cls.__name__)
         if getattr(cls, flag, None) is True or cls._meta.abstract:
             return []
 
@@ -265,7 +270,7 @@ class CollectionItemBase(PolymorphicModel):
 
     @classmethod
     def _check_template_name(cls, **kwargs):
-        flag = '_{}__BaseCollectionItem'.format(cls.__name__)
+        flag = "_{}__BaseCollectionItem".format(cls.__name__)
         if getattr(cls, flag, None) is True or cls._meta.abstract:
             return []
 
@@ -286,18 +291,19 @@ class CollectionItemBase(PolymorphicModel):
             # добавления. Код ниже не решает проблему, но уменьшает её влияние.
             if self.collection.items.filter(order=self.order).exists():
                 max_order = self.collection.items.aggregate(
-                    order=functions.Coalesce(models.Max('order'), 0)
-                )['order']
+                    order=functions.Coalesce(models.Max("order"), 0)
+                )["order"]
                 self.order = max_order + 1
         super().save(*args, **kwargs)
 
     def as_dict(self) -> Dict[str, Any]:
         return {
             **super().as_dict(),
-            'collectionId': self.collection_id,
-            'item_type': self.item_type,
-            'caption': self.get_caption(),
-            'preview': self.render_preview(),
+            "collectionId": self.collection_id,
+            "itemType": self.item_type,
+            "caption": self.get_caption(),
+            "order": self.order,
+            "preview": self.render_preview(),
         }
 
     def get_collection_class(self) -> Type[CollectionBase]:
@@ -323,7 +329,7 @@ class CollectionItemBase(PolymorphicModel):
                 self.item_type = name
                 break
         else:
-            raise TypeError(_('Unsupported collection item: %s') % type(self).__name__)
+            raise TypeError(_("Unsupported collection item: %s") % type(self).__name__)
 
     def get_caption(self):
         """ Заголовок для виджета в админке """
@@ -336,13 +342,13 @@ class CollectionItemBase(PolymorphicModel):
 
     def get_preview_context(self):
         return {
-            'item': self,
-            'width': settings.COLLECTION_ITEM_PREVIEW_WIDTH,
-            'height': settings.COLLECTION_ITEM_PREVIEW_HEIGTH,
+            "item": self,
+            "width": settings.COLLECTION_ITEM_PREVIEW_WIDTH,
+            "height": settings.COLLECTION_ITEM_PREVIEW_HEIGTH,
         }
 
 
-class CollectionFileItemBase(CollectionItemBase, FileFieldResource):
+class CollectionFileItemBase(CollectionItemBase, FileFieldResource, metaclass=CollectionItemMetaBase):
     """
     Базовый класс элемента галереи, содержащего файл.
     """
@@ -370,7 +376,7 @@ class FilePreviewMixin(models.Model):
     def get_preview_url(self):
         extension = self.extension.lower()  # noqa
         extension = FILE_ICON_OVERRIDES.get(extension, extension)
-        icon_path_template = 'paper_uploads/dist/image/{}.svg'
+        icon_path_template = "paper_uploads/dist/assets/{}.svg"
         icon_path = icon_path_template.format(extension)
         if find(icon_path) is None:
             icon_path = icon_path_template.format(FILE_ICON_DEFAULT)
@@ -386,21 +392,21 @@ class FilePreviewMixin(models.Model):
 
 
 class FileItem(FilePreviewMixin, CollectionFileItemBase):
-    change_form_class = 'paper_uploads.forms.dialogs.collection.FileItemDialog'
-    template_name = 'paper_uploads/collection_item/file.html'
-    preview_template_name = 'paper_uploads/collection_item/preview/file.html'
+    change_form_class = "paper_uploads.forms.dialogs.collection.FileItemDialog"
+    template_name = "paper_uploads/items/file.html"
+    preview_template_name = "paper_uploads/items/preview/file.html"
 
     file = models.FileField(
-        _('file'),
+        _("file"),
         max_length=255,
         storage=upload_storage,
         upload_to=settings.COLLECTION_FILES_UPLOAD_TO,
     )
-    display_name = models.CharField(_('display name'), max_length=255, blank=True)
+    display_name = models.CharField(_("display name"), max_length=255, blank=True)
 
     class Meta(CollectionItemBase.Meta):
-        verbose_name = _('File item')
-        verbose_name_plural = _('File items')
+        verbose_name = _("File item")
+        verbose_name_plural = _("File items")
 
     def save(self, *args, **kwargs):
         if not self.pk and not self.display_name:
@@ -414,7 +420,7 @@ class FileItem(FilePreviewMixin, CollectionFileItemBase):
         self.file = value
 
     def get_file_field(self) -> models.FileField:
-        return self._meta.get_field('file')
+        return self._meta.get_field("file")
 
     @classmethod
     def file_supported(cls, file: File) -> bool:
@@ -422,21 +428,21 @@ class FileItem(FilePreviewMixin, CollectionFileItemBase):
 
 
 class SVGItem(CollectionFileItemBase):
-    change_form_class = 'paper_uploads.forms.dialogs.collection.FileItemDialog'
-    template_name = 'paper_uploads/collection_item/svg.html'
-    preview_template_name = 'paper_uploads/collection_item/preview/svg.html'
+    change_form_class = "paper_uploads.forms.dialogs.collection.FileItemDialog"
+    template_name = "paper_uploads/items/svg.html"
+    preview_template_name = "paper_uploads/items/preview/svg.html"
 
     file = models.FileField(
-        _('file'),
+        _("file"),
         max_length=255,
         storage=upload_storage,
         upload_to=settings.COLLECTION_FILES_UPLOAD_TO,
     )
-    display_name = models.CharField(_('display name'), max_length=255, blank=True)
+    display_name = models.CharField(_("display name"), max_length=255, blank=True)
 
     class Meta(CollectionItemBase.Meta):
-        verbose_name = _('SVG item')
-        verbose_name_plural = _('SVG items')
+        verbose_name = _("SVG item")
+        verbose_name_plural = _("SVG items")
 
     def save(self, *args, **kwargs):
         if not self.pk and not self.display_name:
@@ -450,30 +456,30 @@ class SVGItem(CollectionFileItemBase):
         self.file = value
 
     def get_file_field(self) -> models.FileField:
-        return self._meta.get_field('file')
+        return self._meta.get_field("file")
 
     @classmethod
     def file_supported(cls, file: File) -> bool:
         filename, ext = posixpath.splitext(file.name)
-        return ext.lower() == '.svg'
+        return ext.lower() == ".svg"
 
 
 class ImageItem(VersatileImageResourceMixin, CollectionFileItemBase):
     PREVIEW_VARIATIONS = settings.COLLECTION_IMAGE_ITEM_PREVIEW_VARIATIONS
-    change_form_class = 'paper_uploads.forms.dialogs.collection.ImageItemDialog'
-    template_name = 'paper_uploads/collection_item/image.html'
-    preview_template_name = 'paper_uploads/collection_item/preview/image.html'
+    change_form_class = "paper_uploads.forms.dialogs.collection.ImageItemDialog"
+    template_name = "paper_uploads/items/image.html"
+    preview_template_name = "paper_uploads/items/preview/image.html"
 
     file = VariationalFileField(
-        _('file'),
+        _("file"),
         max_length=255,
         storage=upload_storage,
         upload_to=settings.COLLECTION_IMAGES_UPLOAD_TO,
     )
 
     class Meta(CollectionItemBase.Meta):
-        verbose_name = _('Image item')
-        verbose_name_plural = _('Image items')
+        verbose_name = _("Image item")
+        verbose_name_plural = _("Image items")
 
     def get_file(self) -> FieldFile:
         return self.file
@@ -482,7 +488,7 @@ class ImageItem(VersatileImageResourceMixin, CollectionFileItemBase):
         self.file = value
 
     def get_file_field(self) -> VariationalFileField:
-        return self._meta.get_field('file')
+        return self._meta.get_field("file")
 
     def recut_async(self, names: Iterable[str] = ()):
         """
@@ -502,7 +508,7 @@ class ImageItem(VersatileImageResourceMixin, CollectionFileItemBase):
             2) член класса галереи VARIATIONS
         К найденному словарю примешиваются вариации для админки.
         """
-        if not hasattr(self, '_variations_cache'):
+        if not hasattr(self, "_variations_cache"):
             collection_cls = self.get_collection_class()
             itemtype_field = self.get_itemtype_field()
             variation_config = self.get_variation_config(itemtype_field, collection_cls)
@@ -513,17 +519,17 @@ class ImageItem(VersatileImageResourceMixin, CollectionFileItemBase):
     def file_supported(cls, file: File) -> bool:
         mimetype = magic.from_buffer(file.read(1024), mime=True)
         file.seek(0)  # correct file position after mimetype detection
-        basetype, subtype = mimetype.split('/', 1)
-        return basetype == 'image'
+        basetype, subtype = mimetype.split("/", 1)
+        return basetype == "image"
 
     @classmethod
     def get_variation_config(
-        cls, field: Optional[CollectionItem], collection_cls: Type[CollectionBase]
+        cls, rel: Optional[CollectionItem], collection_cls: Type[CollectionBase]
     ) -> Dict[str, Any]:
-        if field is not None and 'variations' in field.options:
-            variations = field.options['variations']
+        if rel is not None and "variations" in rel.options:
+            variations = rel.options["variations"]
         else:
-            variations = getattr(collection_cls, 'VARIATIONS', None)
+            variations = getattr(collection_cls, "VARIATIONS", None)
         variations = (variations or {}).copy()
         variations.update(cls.PREVIEW_VARIATIONS)
         return variations
@@ -541,8 +547,15 @@ class ImageCollection(Collection):
 
     @classmethod
     def get_configuration(cls) -> Dict[str, Any]:
-        # TODO: магический метод
         return {
-            'image': True,
-            'acceptFiles': ['image/*'],
+            "strictImageValidation": True,
+            "acceptFiles": [
+                "image/bmp",
+                "image/gif",
+                "image/jpeg",
+                "image/png",
+                # "image/svg+xml",
+                "image/tiff",
+                "image/webp",
+            ],
         }
